-- Install lazy.nvim
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not (vim.uv or vim.loop).fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

-- Load lazy.nvim
require("lazy").setup({
  { "nvim-lualine/lualine.nvim", dependencies = 'nvim-tree/nvim-web-devicons'},
  { "folke/zen-mode.nvim", lazy = true, cmd = "ZenMode" },
  "ggandor/leap.nvim",
  "AlphaTechnolog/pywal.nvim",
  { "windwp/nvim-autopairs", event = "InsertEnter", config = true },
  {
      "goolord/alpha-nvim",
      dependencies = { 'nvim-tree/nvim-web-devicons' },
      config = function ()
        require'alpha'.setup(require'alpha.themes.startify'.config)
      end
  },
  {
  "folke/twilight.nvim",
  opts = {
    context = 3;
  }
},
  { "nvim-telescope/telescope.nvim", dependencies = "nvim-lua/plenary.nvim" },
  { "nvim-treesitter/nvim-treesitter", build = ":TSUpdate" },
  {
  "folke/which-key.nvim",
  event = "VeryLazy",
  init = function()
    vim.o.timeout = true
    vim.o.timeoutlen = 300
  end,
},
})

-- Load leap
require('leap').create_default_mappings()

-- Settings
vim.g.mapleader = ";"

vim.opt.timeoutlen = 300
vim.opt.updatetime = 200
vim.g.have_nerd_font = false
vim.opt.breakindent = true
vim.opt.undofile = true
vim.opt.history = 500
vim.opt.so = 7
vim.opt.wildmenu = true
vim.opt.hidden = true
vim.opt.backspace = "eol,start,indent"
vim.opt.ignorecase = true
vim.opt.smartcase = true
vim.opt.hlsearch = true
vim.opt.incsearch = true
vim.opt.lazyredraw = true
vim.opt.magic = true
vim.opt.showmatch = true
vim.opt.matchtime = 2
vim.opt.syntax = "on"
vim.opt.encoding = "utf8"
vim.opt.fileformats = {"unix", "dos", "mac"}
vim.opt.backup = false
vim.opt.writebackup = false
vim.opt.swapfile = false
vim.opt.expandtab = true
vim.opt.smarttab = true
vim.opt.shiftwidth = 4
vim.opt.tabstop = 4
vim.opt.linebreak = true
vim.opt.textwidth = 500
vim.opt.autoindent = true
vim.opt.smartindent = true
vim.opt.wrap = true
vim.opt.title = true
vim.opt.showmode = false
vim.opt.clipboard = "unnamedplus"
vim.opt.compatible = false
vim.opt.fillchars = { eob = " " }
vim.opt.cmdheight = 0
vim.opt.laststatus = 2
vim.opt.inccommand = 'split'
vim.opt.scrolloff = 10
-- vim.opt.number = true

-- Search keybindings
vim.api.nvim_set_keymap("n", "<leader>ff", "<cmd>Telescope find_files hidden=true<cr>", {noremap = true})
vim.api.nvim_set_keymap("n", "<leader>fg", "<cmd>Telescope live_grep hidden=true<cr>", {noremap = true})
vim.api.nvim_set_keymap("n", "<leader>fb", "<cmd>Telescope buffers<cr>", {noremap = true})
vim.api.nvim_set_keymap("n", "<leader>fh", "<cmd>Telescope help_tags<cr>", {noremap = true})
vim.keymap.set('n', '<Esc>', '<cmd>nohlsearch<CR>')

-- No automatic commenting on a new line
vim.api.nvim_create_autocmd("FileType", {
  pattern = "*",
  callback = function()
    vim.opt_local.formatoptions:remove({ "c", "r", "o" })
  end,
})

-- Automatically deletes all trailing whitespace on save
vim.api.nvim_create_autocmd("BufWritePre", {
  pattern = "*",
  callback = function()
    vim.cmd("%s/\\s\\+$//e")
  end
})

-- Set to auto read when a file is changed from the outside
vim.opt.autoread = true
vim.api.nvim_create_autocmd({"FocusGained", "BufEnter"}, {
  pattern = "*",
  command = "checktime"
})

-- Make colorschemes work
local pywal = require('pywal')
pywal.setup()

local lualine = require('lualine')

lualine.setup {
  options = {
    theme = 'pywal-nvim',
  },
}
